@@ -352,7 +352,6 @@ static void move_results_to_core(struct nm_event_execution_properties *evprop) {
 static void move_results_to_core() {
 #endif
     objectlist *tmp_list = NULL;
-    check_result *info = NULL;
 #ifdef USENAEMON
     if(evprop->execution_type == EVENT_EXEC_NORMAL) {
 #endif
@@ -363,8 +362,6 @@ static void move_results_to_core() {
         free(tmp_list);
         process_check_result(mod_gm_result_list->object_ptr);
         free_check_result(mod_gm_result_list->object_ptr);
-        info = mod_gm_result_list->object_ptr;
-        my_free(info->source);
         free(mod_gm_result_list->object_ptr);
         tmp_list = mod_gm_result_list;
     }
@@ -640,27 +637,16 @@ static int handle_notifications( int event_type, void *data ) {
 
     /* grab the host macro variables */
     memset(&mac, 0, sizeof(mac));
-#ifdef USENAGIOS3
-    clear_volatile_macros();
-    grab_host_macros(hst);
-    if(svc != NULL)
-        grab_service_macros(svc);
-#endif
 #if defined(USENAEMON) || defined(USENAGIOS4)
     clear_volatile_macros_r(&mac);
+#endif
     grab_host_macros_r(&mac, hst);
     if(svc != NULL)
         grab_service_macros_r(&mac, svc);
-#endif
 
     /* get the raw command line */
     temp_command = find_command(ds->command_name);
-#ifdef USENAGIOS3
-    get_raw_command_line(temp_command, ds->command_name, &raw_command,macro_options);
-#endif
-#if defined(USENAEMON) || defined(USENAGIOS4)
     get_raw_command_line_r(&mac, temp_command, ds->command_name, &raw_command, macro_options);
-#endif
     if(raw_command==NULL){
         gm_log( GM_LOG_ERROR, "Raw check command for host '%s' was NULL - aborting.\n",hst->name );
         return NEBERROR_CALLBACKCANCEL;
@@ -718,7 +704,9 @@ static int handle_notifications( int event_type, void *data ) {
             mac.x[MACRO_NOTIFICATIONTYPE] = gm_strdup("DOWNTIMECANCELLED");
         else if(ds->reason_type == NOTIFICATION_CUSTOM)
             mac.x[MACRO_NOTIFICATIONTYPE] = gm_strdup("CUSTOM");
-        else if(svc->current_state == STATE_OK)
+        else if(svc != NULL && svc->current_state == STATE_OK)
+            mac.x[MACRO_NOTIFICATIONTYPE] = gm_strdup("RECOVERY");
+        else if(svc == NULL && hst->current_state == STATE_OK)
             mac.x[MACRO_NOTIFICATIONTYPE] = gm_strdup("RECOVERY");
         else
             mac.x[MACRO_NOTIFICATIONTYPE] = gm_strdup("PROBLEM");
@@ -756,12 +744,7 @@ static int handle_notifications( int event_type, void *data ) {
     }
 
     /* process any macros contained in the argument */
-#ifdef USENAGIOS3
-    process_macros(raw_command,&processed_command,0);
-#endif
-#if defined(USENAEMON) || defined(USENAGIOS4)
     process_macros_r(&mac, raw_command, &processed_command, 0);
-#endif
     if(processed_command==NULL){
         gm_log( GM_LOG_ERROR, "Processed check command for host '%s' was NULL - aborting.\n",hst->name);
         return NEBERROR_CALLBACKCANCEL;
@@ -809,30 +792,11 @@ static int handle_notifications( int event_type, void *data ) {
 
     /* log the notification to program log file */
     if (log_notifications == TRUE) {
-#if defined(USENAEMON) || defined(USENAGIOS4)
-        if(svc != NULL) {
-            if(ds->reason_type != NOTIFICATION_NORMAL) {
-                gm_asprintf(&log_buffer, "SERVICE NOTIFICATION: %s;%s;%s;%s ($SERVICESTATE$);%s;**$SERVICEOUTPUT$;$NOTIFICATIONAUTHOR$;$NOTIFICATIONCOMMENT$\n", ds->contact_name, svc->host_name, svc->description, notification_reason_name(ds->reason_type), ds->command_name);
-            } else {
-                gm_asprintf(&log_buffer, "SERVICE NOTIFICATION: %s;%s;%s;$SERVICESTATE$;%s;**$SERVICEOUTPUT$\n", ds->contact_name, svc->host_name, svc->description, ds->command_name);
-            }
-            process_macros_r(&mac, log_buffer, &processed_buffer, 0);
-            log_core(NSLOG_SERVICE_NOTIFICATION, processed_buffer);
-        } else {
-            if(ds->reason_type != NOTIFICATION_NORMAL) {
-                gm_asprintf(&log_buffer, "HOST NOTIFICATION: %s;%s;%s ($HOSTSTATE$);%s;**$HOSTOUTPUT$;$NOTIFICATIONAUTHOR$;$NOTIFICATIONCOMMENT$\n", ds->contact_name, hst->name, notification_reason_name(ds->reason_type), ds->command_name);
-            } else {
-                gm_asprintf(&log_buffer, "HOST NOTIFICATION: %s;%s;$HOSTSTATE$;%s;**$HOSTOUTPUT$\n", ds->contact_name, hst->name, ds->command_name);
-            }
-            process_macros_r(&mac, log_buffer, &processed_buffer, 0);
-            log_core(NSLOG_HOST_NOTIFICATION, processed_buffer);
-        }
-        free(log_buffer);
-        free(processed_buffer);
-#endif
-#if defined(USENAGIOS3)
         if(svc != NULL) {
             switch(ds->reason_type) {
+#if defined(USENAGIOS3)
+                case 8: /* icinga uses a different constant here, so just hardcode the 8 which is not in use in nagios3 right now */
+#endif
                 case NOTIFICATION_CUSTOM:
                     gm_asprintf(&log_buffer, "SERVICE NOTIFICATION: %s;%s;%s;CUSTOM ($SERVICESTATE$);%s;$SERVICEOUTPUT$;$NOTIFICATIONAUTHOR$;$NOTIFICATIONCOMMENT$\n", ds->contact_name, svc->host_name, svc->description, ds->command_name);
                     break;
@@ -862,9 +826,17 @@ static int handle_notifications( int event_type, void *data ) {
                     break;
             }
             process_macros_r(&mac, log_buffer, &processed_buffer, 0);
+#if defined(USENAEMON) || defined(USENAGIOS4)
+            log_core(NSLOG_SERVICE_NOTIFICATION, processed_buffer);
+#endif
+#if defined(USENAGIOS3)
             write_to_all_logs(processed_buffer, NSLOG_SERVICE_NOTIFICATION);
+#endif
         } else {
             switch(ds->reason_type) {
+#if defined(USENAGIOS3)
+                case 8: /* icinga uses a different constant here, so just hardcode the 8 which is not in use in nagios3 right now */
+#endif
                 case NOTIFICATION_CUSTOM:
                     gm_asprintf(&log_buffer, "HOST NOTIFICATION: %s;%s;CUSTOM ($HOSTSTATE$);%s;$HOSTOUTPUT$;$NOTIFICATIONAUTHOR$;$NOTIFICATIONCOMMENT$\n", ds->contact_name, hst->name, ds->command_name);
                     break;
@@ -894,18 +866,26 @@ static int handle_notifications( int event_type, void *data ) {
                     break;
             }
             process_macros_r(&mac, log_buffer, &processed_buffer, 0);
+#if defined(USENAEMON) || defined(USENAGIOS4)
             log_core(NSLOG_HOST_NOTIFICATION, processed_buffer);
+#endif
+#if defined(USENAGIOS3)
+            write_to_all_logs(processed_buffer, NSLOG_HOST_NOTIFICATION);
+#endif
         }
         free(log_buffer);
         free(processed_buffer);
-#endif
     }
 
-
-
-#if defined(USENAEMON)
+#if defined(USENAEMON) || defined(USENAGIOS4)
     clear_volatile_macros_r(&mac);
 #endif
+#if defined(USENAGIOS3)
+    clear_summary_macros_r(&mac);
+    clear_argv_macros_r(&mac);
+    clear_host_macros_r(&mac);
+    clear_service_macros_r(&mac);
+#endif
 
     /* clear out all macros we created */
     free(mac.x[MACRO_NOTIFICATIONNUMBER]);
